@@ -1,9 +1,16 @@
 #!/usr/bin/env seed
 
+imports.gi.versions.Clutter = "0.8";
+
+Clutter = imports.gi.Clutter;
+GLib = imports.gi.GLib;
+
+Clutter.init(Seed.argv);
+
 Seed.include("transition-library.js");
 
 var stage = new Clutter.Stage();
-stage.signal.hide.connect(function(){Clutter.main_quit();});
+stage.signal.hide.connect(Clutter.main_quit);
 stage.set_size(1024,768);
 stage.show_all();
 
@@ -66,7 +73,11 @@ function animate()
 	stage.add_actor(at);
 	stage.show_all();
 
-	GLib.timeout_add(500, next_transition);
+	//GLib.timeout_add(500, next_transition);
+	trtimeline = new Clutter.Timeline();
+	trtimeline.duration = 500;
+	trtimeline.signal.completed.connect(next_transition);
+	trtimeline.start();
 }
 
 animate();
