@@ -59,14 +59,34 @@ seed_gobject_destroyed (gpointer object)
   JSObjectSetPrivate ((JSObjectRef) object, 0);
 }
 
+JSObjectRef
+seed_make_wrapper_for_type (JSContextRef ctx, GType type)
+{
+  JSClassRef class;
+  JSObjectRef ret;
+  JSValueRef prototype;
+  
+  class = seed_gobject_get_class_for_gtype (ctx, type);
+  
+  while (!class && (type = g_type_parent (type)))
+    class = seed_gobject_get_class_for_gtype (ctx, type);
+  
+  prototype = seed_gobject_get_prototype_for_gtype (type);
+  ret = JSObjectMake (ctx, class, NULL);
+  if (prototype)
+    JSObjectSetPrototype (ctx, ret, prototype);
+  else
+    g_assert_not_reached();
+  
+  return ret;
+}
+
 static JSValueRef
 seed_wrap_object (JSContextRef ctx, GObject * object)
 {
   JSValueRef user_data;
-  JSValueRef js_ref;
-  JSClassRef class;
+  JSObjectRef js_ref;
   GType type;
-  JSValueRef prototype;
 
   type = G_OBJECT_TYPE (object);
 
@@ -75,27 +95,22 @@ seed_wrap_object (JSContextRef ctx, GObject * object)
   if (user_data)
     return user_data;
 
-  class = seed_gobject_get_class_for_gtype (ctx, type);
-
-  while (!class && (type = g_type_parent (type)))
-    {
-      class = seed_gobject_get_class_for_gtype (ctx, type);
-    }
-
-  prototype = seed_gobject_get_prototype_for_gtype (type);
-  js_ref = JSObjectMake (ctx, class, object);
-  if (prototype)
-    JSObjectSetPrototype (ctx, (JSObjectRef) js_ref, prototype);
+  if (seed_next_gobject_wrapper)
+    js_ref = seed_next_gobject_wrapper;
   else
-    {
-      g_assert_not_reached ();
-    }
+    js_ref = seed_make_wrapper_for_type (ctx, type);
+
+  JSObjectSetPrivate (js_ref, object);
 
   g_object_set_qdata_full (object, js_ref_quark, (gpointer) js_ref,
 			  seed_gobject_destroyed);
 
   JSValueProtect (eng->context, js_ref);
   g_object_add_toggle_ref (object, seed_toggle_ref, (gpointer) js_ref);
+  
+  seed_add_signals_to_object (ctx, js_ref, object);
+  
+  seed_next_gobject_wrapper = NULL;
 
   return js_ref;
 }
@@ -445,7 +460,9 @@ seed_gi_make_array (JSContextRef ctx,
 gboolean
 seed_gi_make_argument (JSContextRef ctx,
 		       JSValueRef value,
-		       GITypeInfo * type_info, GArgument * arg,
+		       GITypeInfo * type_info, 
+		       GIArgInfo *arg_info,
+		       GArgument * arg,
 		       JSValueRef * exception)
 {
   GITypeTag gi_tag = g_type_info_get_tag (type_info);
@@ -516,6 +533,9 @@ seed_gi_make_argument (JSContextRef ctx,
     case GI_TYPE_TAG_GTYPE:
       arg->v_int = seed_value_to_int (ctx, value, exception);
       break;
+    case GI_TYPE_TAG_TIME_T:
+      arg->v_long = seed_value_to_time_t (ctx, value, exception);
+      break;
     case GI_TYPE_TAG_INTERFACE:
       {
 	GIBaseInfo *interface;
@@ -671,6 +691,7 @@ seed_gi_make_argument (JSContextRef ctx,
 	      {
 		SeedNativeClosure *privates = seed_make_native_closure (ctx,
 									(GICallableInfo *) interface,
+									arg_info,
 									value);
 		arg->v_pointer = privates->closure;
 		g_base_info_unref (interface);
@@ -773,6 +794,8 @@ seed_gi_argument_make_js (JSContextRef ctx,
       return seed_value_from_filename (ctx, arg->v_string, exception);
     case GI_TYPE_TAG_GTYPE:
       return seed_value_from_int (ctx, arg->v_int, exception);
+    case GI_TYPE_TAG_TIME_T:
+      return seed_value_from_time_t (ctx, arg->v_long, exception);
     case GI_TYPE_TAG_ARRAY:
       {
 	GITypeInfo *param_type;
@@ -1264,7 +1287,7 @@ gboolean
 seed_value_to_boolean (JSContextRef ctx,
 		       JSValueRef val, JSValueRef * exception)
 {
-  if (!JSValueIsBoolean (ctx, val))
+  if (!JSValueIsBoolean (ctx, val) && !JSValueIsNumber (ctx, val))
     {
       if (!JSValueIsNull (ctx, val))
 	{
@@ -1311,7 +1334,7 @@ seed_value_from_boolean (JSContextRef ctx,
 guint
 seed_value_to_uint (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
 {
-  if (!JSValueIsNumber (ctx, val))
+  if (!JSValueIsNumber (ctx, val) && !JSValueIsBoolean (ctx, val))
     {
       if (!JSValueIsNull (ctx, val))
 	{
@@ -1356,7 +1379,7 @@ seed_value_from_uint (JSContextRef ctx, guint val, JSValueRef * exception)
 gint
 seed_value_to_int (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
 {
-  if (!JSValueIsNumber (ctx, val))
+  if (!JSValueIsNumber (ctx, val) && !JSValueIsBoolean (ctx, val))
     {
       if (!JSValueIsNull (ctx, val))
 	seed_make_exception (ctx, exception, "ConversionError",
@@ -1504,7 +1527,7 @@ seed_value_from_uchar (JSContextRef ctx, guchar val, JSValueRef * exception)
 glong
 seed_value_to_long (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
 {
-  if (!JSValueIsNumber (ctx, val))
+  if (!JSValueIsNumber (ctx, val) && !JSValueIsBoolean (ctx, val))
     {
       if (!JSValueIsNull (ctx, val))
 	seed_make_exception (ctx, exception, "ConversionError",
@@ -1589,7 +1612,7 @@ seed_value_from_ulong (JSContextRef ctx, gulong val, JSValueRef * exception)
 gint64
 seed_value_to_int64 (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
 {
-  if (!JSValueIsNumber (ctx, val))
+  if (!JSValueIsNumber (ctx, val) && !JSValueIsBoolean (ctx, val))
     {
       if (!JSValueIsNull (ctx, val))
 	seed_make_exception (ctx, exception, "ConversionError",
@@ -1633,7 +1656,7 @@ guint64
 seed_value_to_uint64 (JSContextRef ctx,
 		      JSValueRef val, JSValueRef * exception)
 {
-  if (!JSValueIsNumber (ctx, val))
+  if (!JSValueIsNumber (ctx, val) && !JSValueIsBoolean (ctx, val))
     {
       if (!JSValueIsNull (ctx, val))
 	seed_make_exception (ctx, exception, "ConversionError",
@@ -1951,3 +1974,53 @@ seed_validate_enum (GIEnumInfo *info,
   
   return FALSE;
 }
+
+JSValueRef
+seed_value_from_time_t (JSContextRef ctx,
+			time_t time,
+			JSValueRef *exception)
+{
+  JSValueRef args[1];
+  
+  args[0] = seed_value_from_double (ctx, ((gdouble)time)*1000, exception);
+  return JSObjectMakeDate(ctx, 1, args, exception);
+}
+
+time_t
+seed_value_to_time_t (JSContextRef ctx,
+		      JSValueRef value,
+		      JSValueRef *exception)
+{
+  if (JSValueIsNumber (ctx, value))
+    {
+      return (unsigned long) seed_value_to_long (ctx, value, exception);
+    }
+  else if (JSValueIsObject (ctx, value))
+    {
+      JSValueRef get_time_method;
+      JSValueRef jstime;
+      gdouble time;
+      
+      get_time_method = seed_object_get_property (ctx, (JSObjectRef)value,
+						  "getTime");
+      if (JSValueIsNull(ctx, get_time_method) ||
+	  !JSValueIsObject(ctx, get_time_method))
+	{
+	  goto out;
+	}
+      jstime = JSObjectCallAsFunction (ctx, 
+				       (JSObjectRef)get_time_method,
+				       (JSObjectRef)value,
+				       0, NULL,
+				       exception);
+      time = seed_value_to_double (ctx, jstime, exception);
+      return (unsigned long)(time/1000);
+    }
+
+ out:
+  seed_make_exception (ctx, exception,
+		       "TypeError",
+		       "Unable to convert JavaScript value to time_t");
+  return 0;
+}
+
